Enum ScalarMulState
pub enum ScalarMulState {
Show 19 variants
Idle,
TableLaunch,
TableNiels,
TableStore,
TableBaseIssue,
TableBaseCapture,
TableBaseLoad,
TableAddLaunch,
TableAdd,
TableNextNiels,
RecodeWait,
DigitDouble,
DigitCapture,
SelectIssue,
SelectCapture,
SelectLoad,
AddLaunch,
DigitAdd,
Done,
}Expand description
Table-generation, recoding, fixed scan, point-operation, and completion states.
Variants
Idle
Waiting for a scalar-multiplication request.
TableLaunch
Launch conversion of the next generated multiple to Niels form.
TableNiels
Wait for the Niels conversion result.
TableStore
Store forty words of the current Niels table entry.
TableBaseIssue
Issue a BRAM read of the previous multiple used to build the next entry.
TableBaseCapture
Capture the synchronous BRAM result.
TableBaseLoad
Load one captured Niels word into the point controller.
TableAddLaunch
Launch addition of P to form the next positive multiple.
TableAdd
Wait for table-generation point addition.
TableNextNiels
Convert the newly generated multiple to Niels form.
RecodeWait
Wait until all 64 signed digits have been written.
DigitDouble
Wait for one of the four doublings between radix-16 digits.
DigitCapture
Capture the completed doubling and decide whether more are required.
SelectIssue
Issue the same word address to all eight magnitude banks.
SelectCapture
Capture all eight candidate words and select the requested magnitude.
SelectLoad
Load one selected Niels word into the point controller.
AddLaunch
Launch fixed-schedule mixed addition for the current signed digit.
DigitAdd
Wait for the digit addition and advance to the next digit.
Done
Present the completed scalar-multiplication result.